@@ -7,7 +7,8 @@ use GRID::Machine::Group qw{void};
 
 $Data::Dumper::Terse = 1;
 
-my @MACHINE_NAMES = split /\s+/, $ENV{MACHINES};
+my @MACHINE_NAMES = split /\s+/, ($ENV{MACHINES} || '');
+@MACHINE_NAMES = ('', '') unless @MACHINE_NAMES;
 my @m = map { GRID::Machine->new(host => $_) } @MACHINE_NAMES;
 
 my $group = GRID::Machine::Group->new(cluster => \@m);
